import {
  select,
  scaleBand,
  scaleLinear,
  csv,
  extent,
  autoType,
  range,
  axisBottom,
  axisLeft,
  rangeRound,
  max,
} from 'd3';

import { menu } from '/button.js';

const width = 900;
const height = 490;

const margin = {
  top: 70,
  right: 0,
  bottom: 30,
  left: 50,
};

const xValue = (d) => d.month;
const yValue = (d) => {
  return d.revenue;
};

const updatedValue = (d) => {
  return d.profit;
};

const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const main = async () => {
  const data = await csv(
    'revenues.csv',
    autoType
  );

  const options = ['revenue', 'profit'];

  const selection = select('body')
    .append('select')
    .attr('id', 'my-select')
    .selectAll('option')
    .data(options)
    .join('option')
    .text((d) => d)
    .property('value', (d) => d);

  const x = scaleBand()
    .domain(data.map((d) => d.month))
    .rangeRound([
      margin.left,
      width - margin.right,
    ])
    .padding(0.1);

  const y = scaleLinear()
    .domain([0, max(data, (d) => d.revenue)])
    .range([height - margin.bottom, 0]);

  const marks = data.map((d) => {
    return {
      x: x(xValue(d)),
      y: y(yValue(d)),
    };
  });

  const updatedMarks = data.map((d) => {
    return {
      x: x(xValue(d)),
      y: y(updatedValue(d)),
    };
  });

  svg
    .append('g')
    .attr(
      'transform',
      `translate(0, ${height - margin.bottom})`
    )
    .call(axisBottom(x));

  svg
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left}, 0)`
    )
    .call(axisLeft(y).ticks(null, '$2f'));

  svg
    .append('g')
    .attr('fill', 'steelblue')
    .selectAll('rect')
    .data(marks)
    .join('rect')
    .attr('x', (d) => d.x)
    .attr('y', (d) => d.y)
    .attr('height', (d) => y(0) - d.y)
    .attr('width', x.bandwidth());

  select('#my-select').on('change', function (d) {
    const t = svg.transition().duration(750);
    console.log(y(yValue(d)))
  });
};

main();
